/*
 * A finite state machine implemented in C.
 */

#include <stdio.h>
#include <ctype.h>

#define STATE_S0	1	/* initial state */
#define STATE_S1	2	/* leading '-' seen */
#define STATE_S2	3	/* valid number seen */
#define STATE_S3	4	/* error state */

static int
match(const char *s)
{
    const char *p;
    int state = STATE_S0;

    for (p = s; *p; p++) {
	switch (state) {
	    
	case STATE_S0:
	    if (*p == '-') {
		state = STATE_S1;
	    } else if (isdigit(*p)) {
		state = STATE_S2;
	    } else {
		state = STATE_S3;
	    }
	    break;
	    
	case STATE_S1:
	    if (isdigit(*p)) {
                state = STATE_S2;
	    } else {
		state = STATE_S3;
	    }
	    break;
	    
	case STATE_S2:
	    if (isdigit(*p)) {
                state = STATE_S2;
	    } else {
		state = STATE_S3;
	    }
	    break;
	    
	case STATE_S3:
	    break;
	}
    }

    return (state == STATE_S2);
}

int
main(int argc, char *argv[])
{
    int i;

    for (i = 1; i < argc; i++) {
        if (match(argv[i])) {
            printf("%s: pass\n", argv[i]);
        } else {
            printf("%s: fail\n", argv[i]);
        }
    }
    return 0;
}
